@@ -202,6 +202,21 @@ class DestinationSameError(BadRequestError):
         )
 
 
+class DestinationSiteMismatchError(BadRequestError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class DoesNotSupportSortingError(BadRequestError):
     def __init__(
         self,
@@ -247,6 +262,21 @@ class FoldersNotAllowedError(BadRequestError):
         )
 
 
+class InternalGeneralErrorError(BadRequestError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class InvalidBodyError(BadRequestError):
     def __init__(
         self,
@@ -532,6 +562,21 @@ class InvalidUploadPartSizeError(BadRequestError):
         )
 
 
+class InvalidWorkspaceIdHeaderError(BadRequestError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class MethodNotAllowedError(BadRequestError):
     def __init__(
         self,
@@ -1957,6 +2002,21 @@ class BehaviorNotAllowedOnRemoteServerError(ProcessingFailureError):
         )
 
 
+class BufferedUploadDisabledForThisDestinationError(ProcessingFailureError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class BundleOnlyAllowsPreviewsError(ProcessingFailureError):
     def __init__(
         self,
@@ -1987,6 +2047,21 @@ class BundleOperationRequiresSubfolderError(ProcessingFailureError):
         )
 
 
+class ConfigurationLockedPathError(ProcessingFailureError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class CouldNotCreateParentError(ProcessingFailureError):
     def __init__(
         self,
@@ -2407,6 +2482,21 @@ class InvalidSiteError(ProcessingFailureError):
         )
 
 
+class MetadataNotSupportedOnRemotesError(ProcessingFailureError):
+    def __init__(
+        self,
+        message=None,
+        http_body=None,
+        http_status=None,
+        json_body=None,
+        headers=None,
+        code=None,
+    ):
+        super().__init__(
+            message, http_body, http_status, json_body, headers, code
+        )
+
+
 class ModelSaveErrorError(ProcessingFailureError):
     def __init__(
         self,
