@@ -11,6 +11,7 @@ from files_sdk.error import (  # noqa: F401
 class As2Partner:
     default_attributes = {
         "id": None,  # int64 - ID of the AS2 Partner.
+        "workspace_id": None,  # int64 - ID of the Workspace associated with this AS2 Partner.
         "as2_station_id": None,  # int64 - ID of the AS2 Station associated with this partner.
         "name": None,  # string - The partner's formal AS2 name.
         "uri": None,  # string - Public URI where we will send the AS2 messages (via HTTP/HTTPS).
@@ -42,14 +43,16 @@ class As2Partner:
 
     def set_attributes(self, attributes):
         for attribute, default_value in As2Partner.default_attributes.items():
-            setattr(self, attribute, attributes.get(attribute, default_value))
+            value = attributes.get(attribute, default_value)
+            setattr(self, attribute, value)
 
     def get_attributes(self):
-        return {
+        attrs = {
             k: getattr(self, k, None)
             for k in As2Partner.default_attributes
             if getattr(self, k, None) is not None
         }
+        return attrs
 
     # Parameters:
     #   enable_dedicated_ips - boolean - If `true`, we will use your site's dedicated IPs for all outbound connections to this AS2 Partner.
@@ -165,6 +168,8 @@ class As2Partner:
 # Parameters:
 #   cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
+#   sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `workspace_id`, `as2_station_id` or `name`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `as2_station_id` and `workspace_id`. Valid field combinations are `[ workspace_id, as2_station_id ]`.
 def list(params=None, options=None):
     if not isinstance(params, dict):
         params = {}
@@ -174,6 +179,10 @@ def list(params=None, options=None):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
     if "per_page" in params and not isinstance(params["per_page"], int):
         raise InvalidParameterError("Bad parameter: per_page must be an int")
+    if "sort_by" in params and not isinstance(params["sort_by"], dict):
+        raise InvalidParameterError("Bad parameter: sort_by must be an dict")
+    if "filter" in params and not isinstance(params["filter"], dict):
+        raise InvalidParameterError("Bad parameter: filter must be an dict")
     return ListObj(As2Partner, "GET", "/as2_partners", params, options)
 
 
