@@ -33,17 +33,19 @@ class Behavior:
 
     def set_attributes(self, attributes):
         for attribute, default_value in Behavior.default_attributes.items():
-            setattr(self, attribute, attributes.get(attribute, default_value))
+            value = attributes.get(attribute, default_value)
+            setattr(self, attribute, value)
 
     def get_attributes(self):
-        return {
+        attrs = {
             k: getattr(self, k, None)
             for k in Behavior.default_attributes
             if getattr(self, k, None) is not None
         }
+        return attrs
 
     # Parameters:
-    #   value - string - This field stores a hash of data specific to the type of behavior. See The Behavior Types section for example values for each type of behavior.
+    #   value - object - This field stores a hash of data specific to the type of behavior. See The Behavior Types section for example values for each type of behavior.
     #   attachment_file - file - Certain behaviors may require a file, for instance, the `watermark` behavior requires a watermark image. Attach that file here.
     #   disable_parent_folder_behavior - boolean - If `true`, the parent folder's behavior will be disabled for this folder and its children. This is the main mechanism for canceling out a `recursive` behavior higher in the folder tree.
     #   recursive - boolean - If `true`, behavior is treated as recursive, meaning that it impacts child folders as well.
@@ -62,8 +64,6 @@ class Behavior:
             raise MissingParameterError("Parameter missing: id")
         if "id" in params and not isinstance(params["id"], int):
             raise InvalidParameterError("Bad parameter: id must be an int")
-        if "value" in params and not isinstance(params["value"], str):
-            raise InvalidParameterError("Bad parameter: value must be an str")
         if "name" in params and not isinstance(params["name"], str):
             raise InvalidParameterError("Bad parameter: name must be an str")
         if "description" in params and not isinstance(
@@ -117,7 +117,7 @@ class Behavior:
 #   cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `behavior`.
-#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `impacts_ui` and `behavior`. Valid field combinations are `[ impacts_ui, behavior ]`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `clickwrap_id`, `form_field_set_id`, `impacts_ui`, `remote_server_id` or `behavior`. Valid field combinations are `[ impacts_ui, behavior ]`.
 def list(params=None, options=None):
     if not isinstance(params, dict):
         params = {}
@@ -201,7 +201,7 @@ def list_for(path, params=None, options=None):
 
 
 # Parameters:
-#   value - string - This field stores a hash of data specific to the type of behavior. See The Behavior Types section for example values for each type of behavior.
+#   value - object - This field stores a hash of data specific to the type of behavior. See The Behavior Types section for example values for each type of behavior.
 #   attachment_file - file - Certain behaviors may require a file, for instance, the `watermark` behavior requires a watermark image. Attach that file here.
 #   disable_parent_folder_behavior - boolean - If `true`, the parent folder's behavior will be disabled for this folder and its children. This is the main mechanism for canceling out a `recursive` behavior higher in the folder tree.
 #   recursive - boolean - If `true`, behavior is treated as recursive, meaning that it impacts child folders as well.
@@ -214,8 +214,8 @@ def create(params=None, options=None):
         params = {}
     if not isinstance(options, dict):
         options = {}
-    if "value" in params and not isinstance(params["value"], str):
-        raise InvalidParameterError("Bad parameter: value must be an str")
+    if "value" in params and not isinstance(params["value"], dict):
+        raise InvalidParameterError("Bad parameter: value must be an dict")
     if "disable_parent_folder_behavior" in params and not isinstance(
         params["disable_parent_folder_behavior"], bool
     ):
@@ -272,7 +272,7 @@ def webhook_test(params=None, options=None):
 
 
 # Parameters:
-#   value - string - This field stores a hash of data specific to the type of behavior. See The Behavior Types section for example values for each type of behavior.
+#   value - object - This field stores a hash of data specific to the type of behavior. See The Behavior Types section for example values for each type of behavior.
 #   attachment_file - file - Certain behaviors may require a file, for instance, the `watermark` behavior requires a watermark image. Attach that file here.
 #   disable_parent_folder_behavior - boolean - If `true`, the parent folder's behavior will be disabled for this folder and its children. This is the main mechanism for canceling out a `recursive` behavior higher in the folder tree.
 #   recursive - boolean - If `true`, behavior is treated as recursive, meaning that it impacts child folders as well.
@@ -285,12 +285,12 @@ def update(id, params=None, options=None):
     if not isinstance(options, dict):
         options = {}
     params["id"] = id
-    if "id" in params and not isinstance(params["id"], (str, int, dict)):
+    if "id" in params and not isinstance(params["id"], (dict, str, int)):
         raise InvalidParameterError(
-            "Bad parameter: id must be one of str, int, dict"
+            "Bad parameter: id must be one of dict, str, int"
         )
-    if "value" in params and not isinstance(params["value"], str):
-        raise InvalidParameterError("Bad parameter: value must be an str")
+    if "value" in params and not isinstance(params["value"], dict):
+        raise InvalidParameterError("Bad parameter: value must be an dict")
     if "disable_parent_folder_behavior" in params and not isinstance(
         params["disable_parent_folder_behavior"], bool
     ):
@@ -306,10 +306,10 @@ def update(id, params=None, options=None):
             "Bad parameter: description must be an str"
         )
     if "attachment_delete" in params and not isinstance(
-        params["attachment_delete"], (str, int, dict)
+        params["attachment_delete"], (dict, str, int)
     ):
         raise InvalidParameterError(
-            "Bad parameter: attachment_delete must be one of str, int, dict"
+            "Bad parameter: attachment_delete must be one of dict, str, int"
         )
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
