@@ -38,14 +38,16 @@ class BundleRegistration:
             attribute,
             default_value,
         ) in BundleRegistration.default_attributes.items():
-            setattr(self, attribute, attributes.get(attribute, default_value))
+            value = attributes.get(attribute, default_value)
+            setattr(self, attribute, value)
 
     def get_attributes(self):
-        return {
+        attrs = {
             k: getattr(self, k, None)
             for k in BundleRegistration.default_attributes
             if getattr(self, k, None) is not None
         }
+        return attrs
 
 
 # Parameters:
