@@ -33,14 +33,16 @@ class Permission:
 
     def set_attributes(self, attributes):
         for attribute, default_value in Permission.default_attributes.items():
-            setattr(self, attribute, attributes.get(attribute, default_value))
+            value = attributes.get(attribute, default_value)
+            setattr(self, attribute, value)
 
     def get_attributes(self):
-        return {
+        attrs = {
             k: getattr(self, k, None)
             for k in Permission.default_attributes
             if getattr(self, k, None) is not None
         }
+        return attrs
 
     def delete(self, params=None):
         if not isinstance(params, dict):
