@@ -14,20 +14,25 @@ class SiemHttpDestination:
         "name": None,  # string - Name for this Destination
         "destination_type": None,  # string - Destination Type
         "destination_url": None,  # string - Destination Url
+        "file_destination_path": None,  # string - Applicable only for destination type: file. Destination folder path on Files.com.
+        "file_format": None,  # string - Applicable only for destination type: file. Generated file format.
+        "file_interval_minutes": None,  # int64 - Applicable only for destination type: file. Interval, in minutes, between file deliveries.
         "additional_headers": None,  # object - Additional HTTP Headers included in calls to the destination URL
         "sending_active": None,  # boolean - Whether this SIEM HTTP Destination is currently being sent to or not
         "generic_payload_type": None,  # string - Applicable only for destination type: generic. Indicates the type of HTTP body. Can be json_newline or json_array. json_newline is multiple log entries as JSON separated by newlines. json_array is a single JSON array containing multiple log entries as JSON.
         "splunk_token_masked": None,  # string - Applicable only for destination type: splunk. Authentication token provided by Splunk.
-        "azure_dcr_immutable_id": None,  # string - Applicable only for destination type: azure. Immutable ID of the Data Collection Rule.
+        "azure_dcr_immutable_id": None,  # string - Applicable only for destination types: azure, azure_legacy. Immutable ID of the Data Collection Rule.
         "azure_stream_name": None,  # string - Applicable only for destination type: azure. Name of the stream in the DCR that represents the destination table.
-        "azure_oauth_client_credentials_tenant_id": None,  # string - Applicable only for destination type: azure. Client Credentials OAuth Tenant ID.
-        "azure_oauth_client_credentials_client_id": None,  # string - Applicable only for destination type: azure. Client Credentials OAuth Client ID.
-        "azure_oauth_client_credentials_client_secret_masked": None,  # string - Applicable only for destination type: azure. Client Credentials OAuth Client Secret.
+        "azure_oauth_client_credentials_tenant_id": None,  # string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Tenant ID.
+        "azure_oauth_client_credentials_client_id": None,  # string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Client ID.
+        "azure_oauth_client_credentials_client_secret_masked": None,  # string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Client Secret.
         "qradar_username": None,  # string - Applicable only for destination type: qradar. Basic auth username provided by QRadar.
         "qradar_password_masked": None,  # string - Applicable only for destination type: qradar. Basic auth password provided by QRadar.
         "solar_winds_token_masked": None,  # string - Applicable only for destination type: solar_winds. Authentication token provided by Solar Winds.
         "new_relic_api_key_masked": None,  # string - Applicable only for destination type: new_relic. API key provided by New Relic.
         "datadog_api_key_masked": None,  # string - Applicable only for destination type: datadog. API key provided by Datadog.
+        "action_send_enabled": None,  # boolean - Whether or not sending is enabled for action logs.
+        "action_entries_sent": None,  # int64 - Number of log entries sent for the lifetime of this destination.
         "sftp_action_send_enabled": None,  # boolean - Whether or not sending is enabled for sftp_action logs.
         "sftp_action_entries_sent": None,  # int64 - Number of log entries sent for the lifetime of this destination.
         "ftp_action_send_enabled": None,  # boolean - Whether or not sending is enabled for ftp_action logs.
@@ -80,31 +85,37 @@ class SiemHttpDestination:
             attribute,
             default_value,
         ) in SiemHttpDestination.default_attributes.items():
-            setattr(self, attribute, attributes.get(attribute, default_value))
+            value = attributes.get(attribute, default_value)
+            setattr(self, attribute, value)
 
     def get_attributes(self):
-        return {
+        attrs = {
             k: getattr(self, k, None)
             for k in SiemHttpDestination.default_attributes
             if getattr(self, k, None) is not None
         }
+        return attrs
 
     # Parameters:
     #   name - string - Name for this Destination
     #   additional_headers - object - Additional HTTP Headers included in calls to the destination URL
     #   sending_active - boolean - Whether this SIEM HTTP Destination is currently being sent to or not
     #   generic_payload_type - string - Applicable only for destination type: generic. Indicates the type of HTTP body. Can be json_newline or json_array. json_newline is multiple log entries as JSON separated by newlines. json_array is a single JSON array containing multiple log entries as JSON.
+    #   file_destination_path - string - Applicable only for destination type: file. Destination folder path on Files.com.
+    #   file_format - string - Applicable only for destination type: file. Generated file format.
+    #   file_interval_minutes - int64 - Applicable only for destination type: file. Interval, in minutes, between file deliveries. Valid values are 5, 10, 15, 20, 30, 60, 90, 180, 240, 360.
     #   splunk_token - string - Applicable only for destination type: splunk. Authentication token provided by Splunk.
-    #   azure_dcr_immutable_id - string - Applicable only for destination type: azure. Immutable ID of the Data Collection Rule.
+    #   azure_dcr_immutable_id - string - Applicable only for destination types: azure, azure_legacy. Immutable ID of the Data Collection Rule.
     #   azure_stream_name - string - Applicable only for destination type: azure. Name of the stream in the DCR that represents the destination table.
-    #   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination type: azure. Client Credentials OAuth Tenant ID.
-    #   azure_oauth_client_credentials_client_id - string - Applicable only for destination type: azure. Client Credentials OAuth Client ID.
+    #   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Tenant ID.
+    #   azure_oauth_client_credentials_client_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Client ID.
     #   azure_oauth_client_credentials_client_secret - string - Applicable only for destination type: azure. Client Credentials OAuth Client Secret.
     #   qradar_username - string - Applicable only for destination type: qradar. Basic auth username provided by QRadar.
     #   qradar_password - string - Applicable only for destination type: qradar. Basic auth password provided by QRadar.
     #   solar_winds_token - string - Applicable only for destination type: solar_winds. Authentication token provided by Solar Winds.
     #   new_relic_api_key - string - Applicable only for destination type: new_relic. API key provided by New Relic.
     #   datadog_api_key - string - Applicable only for destination type: datadog. API key provided by Datadog.
+    #   action_send_enabled - boolean - Whether or not sending is enabled for action logs.
     #   sftp_action_send_enabled - boolean - Whether or not sending is enabled for sftp_action logs.
     #   ftp_action_send_enabled - boolean - Whether or not sending is enabled for ftp_action logs.
     #   web_dav_action_send_enabled - boolean - Whether or not sending is enabled for web_dav_action logs.
@@ -138,6 +149,24 @@ class SiemHttpDestination:
             raise InvalidParameterError(
                 "Bad parameter: generic_payload_type must be an str"
             )
+        if "file_destination_path" in params and not isinstance(
+            params["file_destination_path"], str
+        ):
+            raise InvalidParameterError(
+                "Bad parameter: file_destination_path must be an str"
+            )
+        if "file_format" in params and not isinstance(
+            params["file_format"], str
+        ):
+            raise InvalidParameterError(
+                "Bad parameter: file_format must be an str"
+            )
+        if "file_interval_minutes" in params and not isinstance(
+            params["file_interval_minutes"], int
+        ):
+            raise InvalidParameterError(
+                "Bad parameter: file_interval_minutes must be an int"
+            )
         if "splunk_token" in params and not isinstance(
             params["splunk_token"], str
         ):
@@ -317,17 +346,21 @@ def get(id, params=None, options=None):
 #   additional_headers - object - Additional HTTP Headers included in calls to the destination URL
 #   sending_active - boolean - Whether this SIEM HTTP Destination is currently being sent to or not
 #   generic_payload_type - string - Applicable only for destination type: generic. Indicates the type of HTTP body. Can be json_newline or json_array. json_newline is multiple log entries as JSON separated by newlines. json_array is a single JSON array containing multiple log entries as JSON.
+#   file_destination_path - string - Applicable only for destination type: file. Destination folder path on Files.com.
+#   file_format - string - Applicable only for destination type: file. Generated file format.
+#   file_interval_minutes - int64 - Applicable only for destination type: file. Interval, in minutes, between file deliveries. Valid values are 5, 10, 15, 20, 30, 60, 90, 180, 240, 360.
 #   splunk_token - string - Applicable only for destination type: splunk. Authentication token provided by Splunk.
-#   azure_dcr_immutable_id - string - Applicable only for destination type: azure. Immutable ID of the Data Collection Rule.
+#   azure_dcr_immutable_id - string - Applicable only for destination types: azure, azure_legacy. Immutable ID of the Data Collection Rule.
 #   azure_stream_name - string - Applicable only for destination type: azure. Name of the stream in the DCR that represents the destination table.
-#   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination type: azure. Client Credentials OAuth Tenant ID.
-#   azure_oauth_client_credentials_client_id - string - Applicable only for destination type: azure. Client Credentials OAuth Client ID.
+#   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Tenant ID.
+#   azure_oauth_client_credentials_client_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Client ID.
 #   azure_oauth_client_credentials_client_secret - string - Applicable only for destination type: azure. Client Credentials OAuth Client Secret.
 #   qradar_username - string - Applicable only for destination type: qradar. Basic auth username provided by QRadar.
 #   qradar_password - string - Applicable only for destination type: qradar. Basic auth password provided by QRadar.
 #   solar_winds_token - string - Applicable only for destination type: solar_winds. Authentication token provided by Solar Winds.
 #   new_relic_api_key - string - Applicable only for destination type: new_relic. API key provided by New Relic.
 #   datadog_api_key - string - Applicable only for destination type: datadog. API key provided by Datadog.
+#   action_send_enabled - boolean - Whether or not sending is enabled for action logs.
 #   sftp_action_send_enabled - boolean - Whether or not sending is enabled for sftp_action logs.
 #   ftp_action_send_enabled - boolean - Whether or not sending is enabled for ftp_action logs.
 #   web_dav_action_send_enabled - boolean - Whether or not sending is enabled for web_dav_action logs.
@@ -340,7 +373,7 @@ def get(id, params=None, options=None):
 #   exavault_api_request_send_enabled - boolean - Whether or not sending is enabled for exavault_api_request logs.
 #   settings_change_send_enabled - boolean - Whether or not sending is enabled for settings_change logs.
 #   destination_type (required) - string - Destination Type
-#   destination_url (required) - string - Destination Url
+#   destination_url - string - Destination Url
 def create(params=None, options=None):
     if not isinstance(params, dict):
         params = {}
@@ -366,6 +399,22 @@ def create(params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: generic_payload_type must be an str"
         )
+    if "file_destination_path" in params and not isinstance(
+        params["file_destination_path"], str
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: file_destination_path must be an str"
+        )
+    if "file_format" in params and not isinstance(params["file_format"], str):
+        raise InvalidParameterError(
+            "Bad parameter: file_format must be an str"
+        )
+    if "file_interval_minutes" in params and not isinstance(
+        params["file_interval_minutes"], int
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: file_interval_minutes must be an int"
+        )
     if "splunk_token" in params and not isinstance(
         params["splunk_token"], str
     ):
@@ -441,6 +490,12 @@ def create(params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: datadog_api_key must be an str"
         )
+    if "action_send_enabled" in params and not isinstance(
+        params["action_send_enabled"], bool
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: action_send_enabled must be an bool"
+        )
     if "sftp_action_send_enabled" in params and not isinstance(
         params["sftp_action_send_enabled"], bool
     ):
@@ -521,8 +576,6 @@ def create(params=None, options=None):
         )
     if "destination_type" not in params:
         raise MissingParameterError("Parameter missing: destination_type")
-    if "destination_url" not in params:
-        raise MissingParameterError("Parameter missing: destination_url")
     response, options = Api.send_request(
         "POST", "/siem_http_destinations", params, options
     )
@@ -537,17 +590,21 @@ def create(params=None, options=None):
 #   additional_headers - object - Additional HTTP Headers included in calls to the destination URL
 #   sending_active - boolean - Whether this SIEM HTTP Destination is currently being sent to or not
 #   generic_payload_type - string - Applicable only for destination type: generic. Indicates the type of HTTP body. Can be json_newline or json_array. json_newline is multiple log entries as JSON separated by newlines. json_array is a single JSON array containing multiple log entries as JSON.
+#   file_destination_path - string - Applicable only for destination type: file. Destination folder path on Files.com.
+#   file_format - string - Applicable only for destination type: file. Generated file format.
+#   file_interval_minutes - int64 - Applicable only for destination type: file. Interval, in minutes, between file deliveries. Valid values are 5, 10, 15, 20, 30, 60, 90, 180, 240, 360.
 #   splunk_token - string - Applicable only for destination type: splunk. Authentication token provided by Splunk.
-#   azure_dcr_immutable_id - string - Applicable only for destination type: azure. Immutable ID of the Data Collection Rule.
+#   azure_dcr_immutable_id - string - Applicable only for destination types: azure, azure_legacy. Immutable ID of the Data Collection Rule.
 #   azure_stream_name - string - Applicable only for destination type: azure. Name of the stream in the DCR that represents the destination table.
-#   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination type: azure. Client Credentials OAuth Tenant ID.
-#   azure_oauth_client_credentials_client_id - string - Applicable only for destination type: azure. Client Credentials OAuth Client ID.
+#   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Tenant ID.
+#   azure_oauth_client_credentials_client_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Client ID.
 #   azure_oauth_client_credentials_client_secret - string - Applicable only for destination type: azure. Client Credentials OAuth Client Secret.
 #   qradar_username - string - Applicable only for destination type: qradar. Basic auth username provided by QRadar.
 #   qradar_password - string - Applicable only for destination type: qradar. Basic auth password provided by QRadar.
 #   solar_winds_token - string - Applicable only for destination type: solar_winds. Authentication token provided by Solar Winds.
 #   new_relic_api_key - string - Applicable only for destination type: new_relic. API key provided by New Relic.
 #   datadog_api_key - string - Applicable only for destination type: datadog. API key provided by Datadog.
+#   action_send_enabled - boolean - Whether or not sending is enabled for action logs.
 #   sftp_action_send_enabled - boolean - Whether or not sending is enabled for sftp_action logs.
 #   ftp_action_send_enabled - boolean - Whether or not sending is enabled for ftp_action logs.
 #   web_dav_action_send_enabled - boolean - Whether or not sending is enabled for web_dav_action logs.
@@ -602,6 +659,22 @@ def send_test_entry(params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: generic_payload_type must be an str"
         )
+    if "file_destination_path" in params and not isinstance(
+        params["file_destination_path"], str
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: file_destination_path must be an str"
+        )
+    if "file_format" in params and not isinstance(params["file_format"], str):
+        raise InvalidParameterError(
+            "Bad parameter: file_format must be an str"
+        )
+    if "file_interval_minutes" in params and not isinstance(
+        params["file_interval_minutes"], int
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: file_interval_minutes must be an int"
+        )
     if "splunk_token" in params and not isinstance(
         params["splunk_token"], str
     ):
@@ -677,6 +750,12 @@ def send_test_entry(params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: datadog_api_key must be an str"
         )
+    if "action_send_enabled" in params and not isinstance(
+        params["action_send_enabled"], bool
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: action_send_enabled must be an bool"
+        )
     if "sftp_action_send_enabled" in params and not isinstance(
         params["sftp_action_send_enabled"], bool
     ):
@@ -753,17 +832,21 @@ def send_test_entry(params=None, options=None):
 #   additional_headers - object - Additional HTTP Headers included in calls to the destination URL
 #   sending_active - boolean - Whether this SIEM HTTP Destination is currently being sent to or not
 #   generic_payload_type - string - Applicable only for destination type: generic. Indicates the type of HTTP body. Can be json_newline or json_array. json_newline is multiple log entries as JSON separated by newlines. json_array is a single JSON array containing multiple log entries as JSON.
+#   file_destination_path - string - Applicable only for destination type: file. Destination folder path on Files.com.
+#   file_format - string - Applicable only for destination type: file. Generated file format.
+#   file_interval_minutes - int64 - Applicable only for destination type: file. Interval, in minutes, between file deliveries. Valid values are 5, 10, 15, 20, 30, 60, 90, 180, 240, 360.
 #   splunk_token - string - Applicable only for destination type: splunk. Authentication token provided by Splunk.
-#   azure_dcr_immutable_id - string - Applicable only for destination type: azure. Immutable ID of the Data Collection Rule.
+#   azure_dcr_immutable_id - string - Applicable only for destination types: azure, azure_legacy. Immutable ID of the Data Collection Rule.
 #   azure_stream_name - string - Applicable only for destination type: azure. Name of the stream in the DCR that represents the destination table.
-#   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination type: azure. Client Credentials OAuth Tenant ID.
-#   azure_oauth_client_credentials_client_id - string - Applicable only for destination type: azure. Client Credentials OAuth Client ID.
+#   azure_oauth_client_credentials_tenant_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Tenant ID.
+#   azure_oauth_client_credentials_client_id - string - Applicable only for destination types: azure, azure_legacy. Client Credentials OAuth Client ID.
 #   azure_oauth_client_credentials_client_secret - string - Applicable only for destination type: azure. Client Credentials OAuth Client Secret.
 #   qradar_username - string - Applicable only for destination type: qradar. Basic auth username provided by QRadar.
 #   qradar_password - string - Applicable only for destination type: qradar. Basic auth password provided by QRadar.
 #   solar_winds_token - string - Applicable only for destination type: solar_winds. Authentication token provided by Solar Winds.
 #   new_relic_api_key - string - Applicable only for destination type: new_relic. API key provided by New Relic.
 #   datadog_api_key - string - Applicable only for destination type: datadog. API key provided by Datadog.
+#   action_send_enabled - boolean - Whether or not sending is enabled for action logs.
 #   sftp_action_send_enabled - boolean - Whether or not sending is enabled for sftp_action logs.
 #   ftp_action_send_enabled - boolean - Whether or not sending is enabled for ftp_action logs.
 #   web_dav_action_send_enabled - boolean - Whether or not sending is enabled for web_dav_action logs.
@@ -805,6 +888,22 @@ def update(id, params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: generic_payload_type must be an str"
         )
+    if "file_destination_path" in params and not isinstance(
+        params["file_destination_path"], str
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: file_destination_path must be an str"
+        )
+    if "file_format" in params and not isinstance(params["file_format"], str):
+        raise InvalidParameterError(
+            "Bad parameter: file_format must be an str"
+        )
+    if "file_interval_minutes" in params and not isinstance(
+        params["file_interval_minutes"], int
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: file_interval_minutes must be an int"
+        )
     if "splunk_token" in params and not isinstance(
         params["splunk_token"], str
     ):
@@ -880,6 +979,12 @@ def update(id, params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: datadog_api_key must be an str"
         )
+    if "action_send_enabled" in params and not isinstance(
+        params["action_send_enabled"], bool
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: action_send_enabled must be an bool"
+        )
     if "sftp_action_send_enabled" in params and not isinstance(
         params["sftp_action_send_enabled"], bool
     ):
