@@ -14,6 +14,7 @@ class Sync:
         "name": None,  # string - Name for this sync job
         "description": None,  # string - Description for this sync job
         "site_id": None,  # int64 - Site ID this sync belongs to
+        "workspace_id": None,  # int64 - Workspace ID this sync belongs to
         "user_id": None,  # int64 - User who created or owns this sync
         "src_path": None,  # string - Absolute source path for the sync
         "dest_path": None,  # string - Absolute destination path for the sync
@@ -49,14 +50,16 @@ class Sync:
 
     def set_attributes(self, attributes):
         for attribute, default_value in Sync.default_attributes.items():
-            setattr(self, attribute, attributes.get(attribute, default_value))
+            value = attributes.get(attribute, default_value)
+            setattr(self, attribute, value)
 
     def get_attributes(self):
-        return {
+        attrs = {
             k: getattr(self, k, None)
             for k in Sync.default_attributes
             if getattr(self, k, None) is not None
         }
+        return attrs
 
     # Dry Run Sync
     def dry_run(self, params=None):
@@ -105,7 +108,6 @@ class Sync:
     #   dest_path - string - Absolute destination path
     #   src_remote_server_id - int64 - Remote server ID for the source
     #   dest_remote_server_id - int64 - Remote server ID for the destination
-    #   two_way - boolean - Is this a two-way sync?
     #   keep_after_copy - boolean - Keep files after copying?
     #   delete_empty_folders - boolean - Delete empty folders after sync?
     #   disabled - boolean - Is this sync disabled?
@@ -252,6 +254,8 @@ class Sync:
 # Parameters:
 #   cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
+#   sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `site_id`, `workspace_id` or `name`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `workspace_id`, `disabled`, `src_remote_server_id` or `dest_remote_server_id`. Valid field combinations are `[ workspace_id, disabled ]`, `[ workspace_id, src_remote_server_id ]`, `[ workspace_id, dest_remote_server_id ]`, `[ disabled, src_remote_server_id ]`, `[ disabled, dest_remote_server_id ]`, `[ workspace_id, disabled, src_remote_server_id ]` or `[ workspace_id, disabled, dest_remote_server_id ]`.
 def list(params=None, options=None):
     if not isinstance(params, dict):
         params = {}
@@ -261,6 +265,10 @@ def list(params=None, options=None):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
     if "per_page" in params and not isinstance(params["per_page"], int):
         raise InvalidParameterError("Bad parameter: per_page must be an int")
+    if "sort_by" in params and not isinstance(params["sort_by"], dict):
+        raise InvalidParameterError("Bad parameter: sort_by must be an dict")
+    if "filter" in params and not isinstance(params["filter"], dict):
+        raise InvalidParameterError("Bad parameter: filter must be an dict")
     return ListObj(Sync, "GET", "/syncs", params, options)
 
 
@@ -297,7 +305,6 @@ def get(id, params=None, options=None):
 #   dest_path - string - Absolute destination path
 #   src_remote_server_id - int64 - Remote server ID for the source
 #   dest_remote_server_id - int64 - Remote server ID for the destination
-#   two_way - boolean - Is this a two-way sync?
 #   keep_after_copy - boolean - Keep files after copying?
 #   delete_empty_folders - boolean - Delete empty folders after sync?
 #   disabled - boolean - Is this sync disabled?
@@ -310,6 +317,7 @@ def get(id, params=None, options=None):
 #   schedule_time_zone - string - If trigger is `custom_schedule`, Custom schedule Time Zone for when the sync should be run.
 #   schedule_days_of_week - array(int64) - If trigger is `custom_schedule`, Custom schedule description for when the sync should be run. 0-based days of the week. 0 is Sunday, 1 is Monday, etc.
 #   schedule_times_of_day - array(string) - If trigger is `custom_schedule`, Custom schedule description for when the sync should be run. Times of day in HH:MM format.
+#   workspace_id - int64 - Workspace ID this sync belongs to
 def create(params=None, options=None):
     if not isinstance(params, dict):
         params = {}
@@ -337,8 +345,6 @@ def create(params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: dest_remote_server_id must be an int"
         )
-    if "two_way" in params and not isinstance(params["two_way"], bool):
-        raise InvalidParameterError("Bad parameter: two_way must be an bool")
     if "keep_after_copy" in params and not isinstance(
         params["keep_after_copy"], bool
     ):
@@ -399,6 +405,12 @@ def create(params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: schedule_times_of_day must be an list"
         )
+    if "workspace_id" in params and not isinstance(
+        params["workspace_id"], int
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: workspace_id must be an int"
+        )
     response, options = Api.send_request("POST", "/syncs", params, options)
     return Sync(response.data, options)
 
@@ -445,7 +457,6 @@ def manual_run(id, params=None, options=None):
 #   dest_path - string - Absolute destination path
 #   src_remote_server_id - int64 - Remote server ID for the source
 #   dest_remote_server_id - int64 - Remote server ID for the destination
-#   two_way - boolean - Is this a two-way sync?
 #   keep_after_copy - boolean - Keep files after copying?
 #   delete_empty_folders - boolean - Delete empty folders after sync?
 #   disabled - boolean - Is this sync disabled?
@@ -488,8 +499,6 @@ def update(id, params=None, options=None):
         raise InvalidParameterError(
             "Bad parameter: dest_remote_server_id must be an int"
         )
-    if "two_way" in params and not isinstance(params["two_way"], bool):
-        raise InvalidParameterError("Bad parameter: two_way must be an bool")
     if "keep_after_copy" in params and not isinstance(
         params["keep_after_copy"], bool
     ):
