@@ -67,7 +67,9 @@ class User:
         "self_managed": None,  # boolean - Does this user manage it's own credentials or is it a shared/bot user?
         "sftp_permission": None,  # boolean - Can the user access with SFTP?
         "site_admin": None,  # boolean - Is the user an administrator for this site?
+        "workspace_admin": None,  # boolean - Is the user a Workspace administrator?  Applicable only to the workspace ID related to this user, if one is set.
         "site_id": None,  # int64 - Site ID
+        "workspace_id": None,  # int64 - Workspace ID
         "skip_welcome_screen": None,  # boolean - Skip Welcome page in the UI?
         "ssl_required": None,  # string - SSL required setting
         "sso_strategy_id": None,  # int64 - SSO (Single Sign On) strategy ID for the user, if applicable.
@@ -105,14 +107,16 @@ class User:
 
     def set_attributes(self, attributes):
         for attribute, default_value in User.default_attributes.items():
-            setattr(self, attribute, attributes.get(attribute, default_value))
+            value = attributes.get(attribute, default_value)
+            setattr(self, attribute, value)
 
     def get_attributes(self):
-        return {
+        attrs = {
             k: getattr(self, k, None)
             for k in User.default_attributes
             if getattr(self, k, None) is not None
         }
+        return attrs
 
     # Unlock user who has been locked out due to failed logins
     def unlock(self, params=None):
@@ -225,6 +229,7 @@ class User:
     #   time_zone - string - User time zone
     #   user_root - string - Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.
     #   user_home - string - Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.
+    #   workspace_admin - boolean - Is the user a Workspace administrator?  Applicable only to the workspace ID related to this user, if one is set.
     #   username - string - User's username
     #   clear_2fa - boolean - If true when changing authentication_method from `password` to `sso`, remove all two-factor methods. Ignored in all other cases.
     #   convert_to_partner_user - boolean - If true, convert this user to a partner user by assigning the partner_id provided.
@@ -438,8 +443,8 @@ class User:
 # Parameters:
 #   cursor - string - Used for pagination.  When a list request has more records available, cursors are provided in the response headers `X-Files-Cursor-Next` and `X-Files-Cursor-Prev`.  Send one of those cursor value here to resume an existing list from the next available record.  Note: many of our SDKs have iterator methods that will automatically handle cursor-based pagination.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `site_id`, `authenticate_until`, `email`, `last_desktop_login_at`, `last_login_at`, `name`, `company`, `password_validity_days`, `ssl_required`, `username`, `site_admin` or `disabled`.
-#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `username`, `name`, `email`, `company`, `site_admin`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until`, `not_site_admin`, `disabled` or `partner_id`. Valid field combinations are `[ site_admin, username ]`, `[ not_site_admin, username ]` or `[ company, name ]`.
+#   sort_by - object - If set, sort records by the specified field in either `asc` or `desc` direction. Valid fields are `site_id`, `workspace_id`, `company`, `name`, `disabled`, `authenticate_until`, `username`, `email`, `last_desktop_login_at`, `last_login_at`, `site_admin`, `password_validity_days` or `ssl_required`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `username`, `name`, `email`, `company`, `site_admin`, `password_validity_days`, `ssl_required`, `last_login_at`, `authenticate_until`, `not_site_admin`, `disabled`, `partner_id` or `workspace_id`. Valid field combinations are `[ site_admin, username ]`, `[ not_site_admin, username ]`, `[ workspace_id, username ]`, `[ company, name ]`, `[ workspace_id, name ]`, `[ workspace_id, email ]`, `[ workspace_id, company ]`, `[ workspace_id, disabled ]`, `[ workspace_id, partner_id ]`, `[ workspace_id, disabled, username ]`, `[ workspace_id, partner_id, username ]` or `[ workspace_id, company, name ]`.
 #   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `password_validity_days`, `last_login_at` or `authenticate_until`.
 #   filter_gteq - object - If set, return records where the specified field is greater than or equal the supplied value. Valid fields are `password_validity_days`, `last_login_at` or `authenticate_until`.
 #   filter_prefix - object - If set, return records where the specified field is prefixed by the supplied value. Valid fields are `username`, `name`, `email` or `company`. Valid field combinations are `[ company, name ]`.
@@ -569,7 +574,9 @@ def get(id, params=None, options=None):
 #   time_zone - string - User time zone
 #   user_root - string - Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.
 #   user_home - string - Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.
+#   workspace_admin - boolean - Is the user a Workspace administrator?  Applicable only to the workspace ID related to this user, if one is set.
 #   username (required) - string - User's username
+#   workspace_id - int64 - Workspace ID
 def create(params=None, options=None):
     if not isinstance(params, dict):
         params = {}
@@ -805,8 +812,20 @@ def create(params=None, options=None):
         raise InvalidParameterError("Bad parameter: user_root must be an str")
     if "user_home" in params and not isinstance(params["user_home"], str):
         raise InvalidParameterError("Bad parameter: user_home must be an str")
+    if "workspace_admin" in params and not isinstance(
+        params["workspace_admin"], bool
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: workspace_admin must be an bool"
+        )
     if "username" in params and not isinstance(params["username"], str):
         raise InvalidParameterError("Bad parameter: username must be an str")
+    if "workspace_id" in params and not isinstance(
+        params["workspace_id"], int
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: workspace_id must be an int"
+        )
     if "username" not in params:
         raise MissingParameterError("Parameter missing: username")
     response, options = Api.send_request("POST", "/users", params, options)
@@ -918,6 +937,7 @@ def user_2fa_reset(id, params=None, options=None):
 #   time_zone - string - User time zone
 #   user_root - string - Root folder for FTP (and optionally SFTP if the appropriate site-wide setting is set).  Note that this is not used for API, Desktop, or Web interface.
 #   user_home - string - Home folder for FTP/SFTP.  Note that this is not used for API, Desktop, or Web interface.
+#   workspace_admin - boolean - Is the user a Workspace administrator?  Applicable only to the workspace ID related to this user, if one is set.
 #   username - string - User's username
 #   clear_2fa - boolean - If true when changing authentication_method from `password` to `sso`, remove all two-factor methods. Ignored in all other cases.
 #   convert_to_partner_user - boolean - If true, convert this user to a partner user by assigning the partner_id provided.
@@ -1159,6 +1179,12 @@ def update(id, params=None, options=None):
         raise InvalidParameterError("Bad parameter: user_root must be an str")
     if "user_home" in params and not isinstance(params["user_home"], str):
         raise InvalidParameterError("Bad parameter: user_home must be an str")
+    if "workspace_admin" in params and not isinstance(
+        params["workspace_admin"], bool
+    ):
+        raise InvalidParameterError(
+            "Bad parameter: workspace_admin must be an bool"
+        )
     if "username" in params and not isinstance(params["username"], str):
         raise InvalidParameterError("Bad parameter: username must be an str")
     if "clear_2fa" in params and not isinstance(params["clear_2fa"], bool):
